@@ -287,7 +287,8 @@ GParamSpec* ObjectPrototype::find_param_spec_from_id(JSContext* cx,
 
     gname = gjs_hyphen_from_camel(js_prop_name);
     GObjectClass *gobj_class = G_OBJECT_CLASS(g_type_class_ref(m_gtype));
-    GjsAutoParam param_spec = g_object_class_find_property(gobj_class, gname);
+    GParamSpec* pspec = g_object_class_find_property(gobj_class, gname);
+    GjsAutoParam param_spec(pspec, GjsAutoParam::TakeOwnership());
     g_type_class_unref(gobj_class);
     g_free(gname);
 
@@ -386,8 +387,10 @@ ObjectInstance::prop_getter_impl(JSContext             *cx,
     if (g_param_spec_get_qdata(param, ObjectInstance::custom_property_quark()))
         return true;
 
-    if ((param->flags & G_PARAM_READABLE) == 0)
+    if ((param->flags & G_PARAM_READABLE) == 0) {
+        rval.setUndefined();
         return true;
+    }
 
     gjs_debug_jsprop(GJS_DEBUG_GOBJECT, "Accessing GObject property %s",
                      param->name);
@@ -691,10 +694,7 @@ static bool is_ginterface_property_name(GIInterfaceInfo* info,
         prop_info.reset();
     }
 
-    if (!prop_info)
-        return false;
-
-    return g_property_info_get_flags(prop_info) & G_PARAM_READABLE;
+    return !!prop_info;
 }
 
 bool ObjectPrototype::lazy_define_gobject_property(JSContext* cx,
@@ -812,14 +812,14 @@ is_gobject_property_name(GIObjectInfo *info,
                 return true;
             }
         }
+
+        g_free(canonical_name);
+        return false;
     }
 
     g_free(canonical_name);
 
-    if (!prop_info)
-        return false;
-
-    return g_property_info_get_flags(prop_info) & G_PARAM_READABLE;
+    return true;
 }
 
 bool ObjectBase::resolve(JSContext* cx, JS::HandleObject obj, JS::HandleId id,
@@ -1618,7 +1618,7 @@ void ObjectBase::finalize(JSFreeOp* fop, JSObject* obj) {
 ObjectInstance::~ObjectInstance() {
     debug_lifecycle("Finalize");
 
-    TRACE(GJS_OBJECT_PROXY_FINALIZE(priv, m_gobj, ns(), name()));
+    TRACE(GJS_OBJECT_PROXY_FINALIZE(this, m_gobj, ns(), name()));
 
     invalidate_all_closures();
 
