@@ -1,4 +1,4 @@
-/* -*- mode: C; c-basic-offset: 4; indent-tabs-mode: nil; -*- */
+/* -*- mode: C++; c-basic-offset: 4; indent-tabs-mode: nil; -*- */
 /*
  * Copyright (c) 2012 Red Hat, Inc.
  *
@@ -63,10 +63,10 @@ _gjs_proxy_to_string_func(JSContext             *context,
     g_string_append_printf(buf, " jsobj@%p", this_obj);
     if (native_address != NULL)
         g_string_append_printf(buf, " native@%p", native_address);
-    
+
     g_string_append_c(buf, ']');
 
-    if (!gjs_string_from_utf8 (context, buf->str, -1, rval))
+    if (!gjs_string_from_utf8(context, buf->str, rval))
         goto out;
 
     ret = true;
@@ -74,3 +74,22 @@ _gjs_proxy_to_string_func(JSContext             *context,
     g_string_free (buf, true);
     return ret;
 }
+
+bool
+_gjs_proxy_throw_nonexistent_field(JSContext  *cx,
+                                   GType       gtype,
+                                   const char *field_name)
+{
+    gjs_throw(cx, "No property %s on %s", field_name, g_type_name(gtype));
+    return false;
+}
+
+bool
+_gjs_proxy_throw_readonly_field(JSContext  *cx,
+                                GType       gtype,
+                                const char *field_name)
+{
+    gjs_throw(cx, "Property %s.%s is not writable", g_type_name(gtype),
+              field_name);
+    return false;
+}
