@@ -110,7 +110,7 @@ function _createSignals(gtype, signals) {
 function _createGTypeName(klass) {
     if (klass.hasOwnProperty(GTypeName))
         return klass[GTypeName];
-    return `Gjs_${klass.name}`;
+    return `Gjs_${klass.name.replace(/[^a-z0-9+_-]/gi, '_')}`;
 }
 
 function _propertiesAsArray(klass) {
