@@ -314,6 +314,11 @@ function _updateTweenByIndex(i) {
                 if (tweening.rounded)
                     nv = Math.round(nv);
 
+                if (tweening.min !== undefined && nv < tweening.min)
+                    nv = tweening.min;
+                if (tweening.max !== undefined && nv > tweening.max)
+                    nv = tweening.max;
+
                 if (property.isSpecialProperty) {
                     // It's a special property, tunnel via the special property method
                     _specialPropertyList[name].setValue(scope, nv, _specialPropertyList[name].parameters, tweening.properties[name].extra);
@@ -381,6 +386,8 @@ var restrictedWords = {
     onOverwrite: true,
     onError: true,
     rounded: true,
+    min: true,
+    max: true,
     onStartParams: true,
     onUpdateParams: true,
     onCompleteParams: true,
@@ -571,6 +578,8 @@ function _addTweenOrCaller(target, tweeningParameters, isCaller) {
         tween.onOverwriteScope         =       obj.onOverwriteScope;
         tween.onErrorScope             =       obj.onErrorScope;
         tween.rounded                  =       obj.rounded;
+        tween.min                      =       obj.min;
+        tween.max                      =       obj.max;
         tween.skipUpdates              =       obj.skipUpdates;
         tween.isCaller                 =       isCaller;
 
